@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::Ast::Any;
 
 # This file auto generated
-#	on Wed 10 Feb  7:50:23 am GMT
+#	on Fri 29 Apr  6:51:34 pm GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.3');
+our $VERSION = version->declare('v0.29.0');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::Ast');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
